<?php

namespace Drupal\sso_trigger\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings for this module.
 */
class SsoTriggerSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sso_trigger_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['sso_trigger.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('sso_trigger.settings');

    $form['sso_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('SSO path'),
      '#default_value' => $config->get('sso_path'),
      '#description' => $this->t('The path to initiate single sign-on. Must start with "/".'),
      '#required' => TRUE,
    ];

    $excluded_paths = $config->get('excluded_paths');

    $form['excluded_paths'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Excluded paths'),
      '#default_value' => $excluded_paths ? implode(PHP_EOL, $excluded_paths) : "",
      '#description' => $this->t('A list of paths that are excluded from the automatic SSO trigger. Enter one path per line, accepts wildcards.'),
    ];

    $blocked_user_message = $config->get('blocked_user_message');

    $form['blocked_user_message'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Blocked user message'),
      '#default_value' => $blocked_user_message['value'],
      '#format' => $blocked_user_message['format'] ?? 'plain_text',
      '#description' => $this->t('Message to show to the user if their account is blocked.'),
    ];

    $form['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable automatic single sign-on'),
      '#default_value' => $config->get('enabled'),
      '#description' => $this->t('Check this box to enable automatic logins; the site will try once to log a visitor in without requiring a click'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (($value = $form_state->getValue('sso_path')) && $value[0] !== '/') {
      $form_state->setErrorByName('sso_path', $this->t("The path '%path' has to start with a slash.", ['%path' => $form_state->getValue('sso_path')]));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('sso_trigger.settings')
      ->set('sso_path', $form_state->getValue('sso_path'))
      ->set('excluded_paths', array_filter(preg_split("/[\r\n\s]+/", $form_state->getValue('excluded_paths'))))
      ->set('blocked_user_message', $form_state->getValue('blocked_user_message'))
      ->set('enabled', $form_state->getValue('enabled'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
